@@ -29,6 +29,6 @@ typedef Eo Efl_Generic_Model;
  */
 #define EFL_GENERIC_MODEL_CLASS efl_generic_model_class_get()
 
-EWAPI const Efl_Class *efl_generic_model_class_get(void);
+EWAPI const Efl_Class *efl_generic_model_class_get(void) EINA_CONST;
 
 #endif
