@@ -20,7 +20,7 @@ typedef Eo Efl_Io_Positioner_Fd;
  */
 #define EFL_IO_POSITIONER_FD_MIXIN efl_io_positioner_fd_mixin_get()
 
-EWAPI const Efl_Class *efl_io_positioner_fd_mixin_get(void);
+EWAPI const Efl_Class *efl_io_positioner_fd_mixin_get(void) EINA_CONST;
 
 #ifdef EFL_IO_POSITIONER_FD_PROTECTED
 /**
