@@ -20,7 +20,7 @@ typedef Eo Efl_Io_Stdin;
  */
 #define EFL_IO_STDIN_CLASS efl_io_stdin_class_get()
 
-EWAPI const Efl_Class *efl_io_stdin_class_get(void);
+EWAPI const Efl_Class *efl_io_stdin_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
