@@ -13,6 +13,7 @@ typedef Eo Efl_Loop_Message;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Base message payload object class. Inherit this and extend for specific
  * message types.
  *
@@ -20,7 +21,7 @@ typedef Eo Efl_Loop_Message;
  */
 #define EFL_LOOP_MESSAGE_CLASS efl_loop_message_class_get()
 
-EWAPI const Efl_Class *efl_loop_message_class_get(void);
+EWAPI const Efl_Class *efl_loop_message_class_get(void) EINA_CONST;
 
 EWAPI extern const Efl_Event_Description _EFL_LOOP_MESSAGE_EVENT_MESSAGE;
 
@@ -30,5 +31,6 @@ EWAPI extern const Efl_Event_Description _EFL_LOOP_MESSAGE_EVENT_MESSAGE;
  * @ingroup Efl_Loop_Message
  */
 #define EFL_LOOP_MESSAGE_EVENT_MESSAGE (&(_EFL_LOOP_MESSAGE_EVENT_MESSAGE))
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
