@@ -20,7 +20,7 @@ typedef Eo Efl_Loop_Message_Future_Handler;
  */
 #define EFL_LOOP_MESSAGE_FUTURE_HANDLER_CLASS efl_loop_message_future_handler_class_get()
 
-EWAPI const Efl_Class *efl_loop_message_future_handler_class_get(void);
+EWAPI const Efl_Class *efl_loop_message_future_handler_class_get(void) EINA_CONST;
 
 /**
  * @brief No description supplied.
