@@ -16,7 +16,7 @@ typedef Eo Efl_Thread;
 #ifdef EFL_BETA_API_SUPPORT
 #define EFL_THREAD_CLASS efl_thread_class_get()
 
-EWAPI const Efl_Class *efl_thread_class_get(void);
+EWAPI const Efl_Class *efl_thread_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
