@@ -26,7 +26,7 @@ typedef Eo Efl_Canvas_Layout_Part;
  */
 #define EFL_CANVAS_LAYOUT_PART_CLASS efl_canvas_layout_part_class_get()
 
-EWAPI const Efl_Class *efl_canvas_layout_part_class_get(void);
+EWAPI const Efl_Class *efl_canvas_layout_part_class_get(void) EINA_CONST;
 
 /**
  * @brief The name and value of the current state of this part (read-only).
