@@ -31,7 +31,7 @@ typedef Eo Efl_Cached_Item;
  */
 #define EFL_CACHED_ITEM_INTERFACE efl_cached_item_interface_get()
 
-EWAPI const Efl_Class *efl_cached_item_interface_get(void);
+EWAPI const Efl_Class *efl_cached_item_interface_get(void) EINA_CONST;
 
 /**
  * @brief The amount of memory currently used by this object.
