@@ -36,7 +36,7 @@ typedef enum
  */
 #define EFL_GFX_FRAME_CONTROLLER_INTERFACE efl_gfx_frame_controller_interface_get()
 
-EWAPI const Efl_Class *efl_gfx_frame_controller_interface_get(void);
+EWAPI const Efl_Class *efl_gfx_frame_controller_interface_get(void) EINA_CONST;
 
 /**
  * @brief Whether an object can be animated (has multiple frames).
