@@ -108,6 +108,7 @@
  *
  * @skip while
  * @until }
+ * @example eina_inlist_01.c
  */
 
 /**
@@ -133,7 +134,7 @@
  * @image rtf eina_inlist-node_eg2-my-struct.png
  * @image latex eina_inlist-node_eg2-my-struct.eps
  *
- * Now we need some pointers and auxiliar variables that will help us iterate on
+ * Now we need some pointers and auxiliary variables that will help us iterate on
  * the lists:
  *
  * @skip struct
@@ -153,10 +154,8 @@
  * The two lists, sharing some elements, can be represented by the following
  * picture:
  *
- * @htmlonly
- * <img src="eina_inlist-node_eg2-list-inlist.png" style="max-width: 100%;"/>
- * @endhtmlonly
  * @image rtf eina_inlist-node_eg2-list-inlist.png
+ * @image html eina_inlist-node_eg2-list-inlist.png
  * @image latex eina_inlist-node_eg2-list-inlist.eps "" width=\textwidth
  *
  * Accessing both lists is done normally, as if they didn't have any elements in
@@ -181,6 +180,7 @@
  * @until }
  *
  * Here is the full source code for this example: @ref eina_inlist_02_c
+ * @example eina_inlist_02.c
  */
 
 /**
@@ -229,10 +229,8 @@
  *
  * And the resulting lists will be as follow:
  *
- * @htmlonly
- * <img src="eina_inlist-node_eg3-two-inlists.png" style="max-width: 100%;"/>
- * @endhtmlonly
  * @image rtf eina_inlist-node_eg3-two-inlists.png
+ * @image html eina_inlist-node_eg3-two-inlists.png
  * @image latex eina_inlist-node_eg3-two-inlists.eps "" width=\textwidth
  *
  * For the first list, we can use the macro @ref EINA_INLIST_FOREACH to iterate
@@ -270,7 +268,7 @@
  *
  * To see the full source code for this example, click here: @ref
  * eina_inlist_03_c
- *
+ * @example eina_inlist_03.c
  */
 
 /**
@@ -415,14 +413,14 @@ struct _Eina_Inlist
 #define EINA_INLIST_GET(Inlist)         (& ((Inlist)->__in_list))
 /** Utility macro to get the container object of an inlist */
 #define EINA_INLIST_CONTAINER_GET(ptr,                          \
-                                  type) ((type *)((char *)ptr - \
+                                  type) ((type *)(void *)((char *)ptr - \
                                                   offsetof(type, __in_list)))
 
 
 /**
- * Add a new node to end of a list.
+ * @brief Adds a new node to end of a list.
  *
- * @note this code is meant to be fast: appends are O(1) and do not
+ * @note This code is meant to be fast: appends are O(1) and do not
  *       walk @a in_list.
  *
  * @note @a in_item is considered to be in no list. If it was in another
@@ -430,18 +428,18 @@ struct _Eina_Inlist
  *       check of @a new_l prev and next pointers is done, so it's safe
  *       to have them uninitialized.
  *
- * @param in_list existing list head or @c NULL to create a new list.
- * @param in_item new list node, must not be @c NULL.
+ * @param[in,out] in_list Existing list head or @c NULL to create a new list.
+ * @param[in] in_item New list node, must not be @c NULL.
  *
- * @return the new list head. Use it and not @a in_list anymore.
+ * @return The new list head. Use it and not @a in_list anymore.
  */
 EAPI Eina_Inlist *eina_inlist_append(Eina_Inlist *in_list,
                                      Eina_Inlist *in_item) EINA_ARG_NONNULL(2) EINA_WARN_UNUSED_RESULT;
 
 /**
- * Add a new node to beginning of list.
+ * @brief Adds a new node to beginning of list.
  *
- * @note this code is meant to be fast: appends are O(1) and do not
+ * @note This code is meant to be fast: appends are O(1) and do not
  *       walk @a in_list.
  *
  * @note @a new_l is considered to be in no list. If it was in another
@@ -449,18 +447,18 @@ EAPI Eina_Inlist *eina_inlist_append(Eina_Inlist *in_list,
  *       check of @a new_l prev and next pointers is done, so it's safe
  *       to have them uninitialized.
  *
- * @param in_list existing list head or @c NULL to create a new list.
- * @param in_item new list node, must not be @c NULL.
+ * @param[in,out] in_list Existing list head or @c NULL to create a new list.
+ * @param[in] in_item New list node, must not be @c NULL.
  *
- * @return the new list head. Use it and not @a in_list anymore.
+ * @return The new list head. Use it and not @a in_list anymore.
  */
 EAPI Eina_Inlist *eina_inlist_prepend(Eina_Inlist *in_list,
                                       Eina_Inlist *in_item) EINA_ARG_NONNULL(2) EINA_WARN_UNUSED_RESULT;
 
 /**
- * Add a new node after the given relative item in list.
+ * @brief Adds a new node after the given relative item in list.
  *
- * @note this code is meant to be fast: appends are O(1) and do not
+ * @note This code is meant to be fast: appends are O(1) and do not
  *       walk @a in_list.
  *
  * @note @a in_item_l is considered to be in no list. If it was in another
@@ -473,20 +471,20 @@ EAPI Eina_Inlist *eina_inlist_prepend(Eina_Inlist *in_list,
  *       will lead to problems. Giving NULL @a in_relative is the same as
  *       eina_list_append().
  *
- * @param in_list existing list head or @c NULL to create a new list.
- * @param in_item new list node, must not be @c NULL.
- * @param in_relative reference node, @a in_item will be added after it.
+ * @param[in,out] in_list Existing list head or @c NULL to create a new list.
+ * @param[in] in_item New list node, must not be @c NULL.
+ * @param[in] in_relative Reference node, @a in_item will be added after it.
  *
- * @return the new list head. Use it and not @a list anymore.
+ * @return The new list head. Use it and not @a list anymore.
  */
 EAPI Eina_Inlist *eina_inlist_append_relative(Eina_Inlist *in_list,
                                               Eina_Inlist *in_item,
                                               Eina_Inlist *in_relative) EINA_ARG_NONNULL(2) EINA_WARN_UNUSED_RESULT;
 
 /**
- * Add a new node before the given relative item in list.
+ * @brief Adds a new node before the given relative item in list.
  *
- * @note this code is meant to be fast: appends are O(1) and do not
+ * @note This code is meant to be fast: appends are O(1) and do not
  *       walk @a in_list.
  *
  * @note @a in_item is considered to be in no list. If it was in another
@@ -499,20 +497,20 @@ EAPI Eina_Inlist *eina_inlist_append_relative(Eina_Inlist *in_list,
  *       will lead to problems. Giving NULL @a in_relative is the same as
  *       eina_list_prepend().
  *
- * @param in_list existing list head or @c NULL to create a new list.
- * @param in_item new list node, must not be @c NULL.
- * @param in_relative reference node, @a in_item will be added before it.
+ * @param[in,out] in_list Existing list head or @c NULL to create a new list.
+ * @param[in] in_item New list node, must not be @c NULL.
+ * @param[in] in_relative Reference node, @a in_item will be added before it.
  *
- * @return the new list head. Use it and not @a in_list anymore.
+ * @return The new list head. Use it and not @a in_list anymore.
  */
 EAPI Eina_Inlist *eina_inlist_prepend_relative(Eina_Inlist *in_list,
                                                Eina_Inlist *in_item,
                                                Eina_Inlist *in_relative) EINA_ARG_NONNULL(2) EINA_WARN_UNUSED_RESULT;
 
 /**
- * Remove node from list.
+ * @brief Removes node from list.
  *
- * @note this code is meant to be fast: appends are O(1) and do not
+ * @note This code is meant to be fast: appends are O(1) and do not
  *       walk @a list.
  *
  * @note @a in_item is considered to be inside @a in_list, no checks are
@@ -521,22 +519,22 @@ EAPI Eina_Inlist *eina_inlist_prepend_relative(Eina_Inlist *in_list,
  *       it will be different from @a list and the wrong new head will
  *       be returned.
  *
- * @param in_list existing list head, must not be @c NULL.
- * @param in_item existing list node, must not be @c NULL.
+ * @param[in,out] in_list Existing list head, must not be @c NULL.
+ * @param[in] in_item Existing list node, must not be @c NULL.
  *
- * @return the new list head. Use it and not @a list anymore.
+ * @return The new list head. Use it and not @a list anymore.
  */
 EAPI Eina_Inlist   *eina_inlist_remove(Eina_Inlist *in_list,
                                        Eina_Inlist *in_item) EINA_ARG_NONNULL(1, 2) EINA_WARN_UNUSED_RESULT;
 
 /**
- * Find given node in list, returns itself if found, NULL if not.
+ * @brief Finds given node in list, returns itself if found, NULL if not.
  *
- * @warning this is an expensive call and has O(n) cost, possibly
+ * @warning This is an expensive call and has O(n) cost, possibly
  *    walking the whole list.
  *
- * @param in_list existing list to search @a in_item in, must not be @c NULL.
- * @param in_item what to search for, must not be @c NULL.
+ * @param[in] in_list Existing list to search @a in_item in, must not be @c NULL.
+ * @param[in] in_item What to search for, must not be @c NULL.
  *
  * @return @a in_item if found, @c NULL if not.
  */
@@ -544,45 +542,45 @@ EAPI Eina_Inlist   *eina_inlist_find(Eina_Inlist *in_list,
                                      Eina_Inlist *in_item) EINA_ARG_NONNULL(2) EINA_WARN_UNUSED_RESULT;
 
 /**
- * Move existing node to beginning of list.
+ * @brief Moves existing node to beginning of list.
  *
- * @note this code is meant to be fast: appends are O(1) and do not
+ * @note This code is meant to be fast: appends are O(1) and do not
  *       walk @a list.
  *
  * @note @a item is considered to be inside @a list. No checks are
  *       done to confirm this, and giving nodes from different lists
  *       will lead to problems.
  *
- * @param list existing list head or @c NULL to create a new list.
- * @param item list node to move to beginning (head), must not be @c NULL.
+ * @param[in] list Existing list head or @c NULL to create a new list.
+ * @param[in] item List node to move to beginning (head), must not be @c NULL.
  *
- * @return the new list head. Use it and not @a list anymore.
+ * @return The new list head. Use it and not @a list anymore.
  */
 EAPI Eina_Inlist   *eina_inlist_promote(Eina_Inlist *list,
                                         Eina_Inlist *item) EINA_ARG_NONNULL(1, 2) EINA_WARN_UNUSED_RESULT;
 
 /**
- * Move existing node to end of list.
+ * @brief Moves existing node to end of list.
  *
- * @note this code is meant to be fast: appends are O(1) and do not
+ * @note This code is meant to be fast: appends are O(1) and do not
  *       walk @a list.
  *
  * @note @a item is considered to be inside @a list. No checks are
  *       done to confirm this, and giving nodes from different lists
  *       will lead to problems.
  *
- * @param list existing list head or @c NULL to create a new list.
- * @param item list node to move to end (tail), must not be @c NULL.
+ * @param[in] list Existing list head or @c NULL to create a new list.
+ * @param[in] item List node to move to end (tail), must not be @c NULL.
  *
- * @return the new list head. Use it and not @a list anymore.
+ * @return The new list head. Use it and not @a list anymore.
  */
 EAPI Eina_Inlist   *eina_inlist_demote(Eina_Inlist *list,
                                        Eina_Inlist *item) EINA_ARG_NONNULL(1, 2) EINA_WARN_UNUSED_RESULT;
 
 /**
- * @brief Get the first list node in the list.
+ * @brief Gets the first list node in the list.
  *
- * @param list The list to get the first list node from.
+ * @param[in] list The list to get the first list node from.
  * @return The first list node in the list.
  *
  * This function returns the first list node in the list @p list. If
@@ -596,9 +594,9 @@ EAPI Eina_Inlist   *eina_inlist_demote(Eina_Inlist *list,
 static inline Eina_Inlist *eina_inlist_first(const Eina_Inlist *list) EINA_PURE EINA_WARN_UNUSED_RESULT;
 
 /**
- * @brief Get the last list node in the list.
+ * @brief Gets the last list node in the list.
  *
- * @param list The list to get the last list node from.
+ * @param[in] list The list to get the last list node from.
  * @return The last list node in the list.
  *
  * This function returns the last list node in the list @p list. If
@@ -612,9 +610,9 @@ static inline Eina_Inlist *eina_inlist_first(const Eina_Inlist *list) EINA_PURE
 static inline Eina_Inlist *eina_inlist_last(const Eina_Inlist *list) EINA_PURE EINA_WARN_UNUSED_RESULT;
 
 /**
- * @brief Get the count of the number of items in a list.
+ * @brief Gets the count of the number of items in a list.
  *
- * @param list The list whose count to return.
+ * @param[in] list The list whose count to return.
  * @return The number of members in the list.
  *
  * This function returns how many members @p list contains. If the
@@ -630,7 +628,7 @@ EAPI unsigned int   eina_inlist_count(const Eina_Inlist *list) EINA_WARN_UNUSED_
 /**
  * @brief Returns a new iterator associated to @a list.
  *
- * @param in_list The list.
+ * @param[in] in_list The list.
  * @return A new iterator.
  *
  * This function returns a newly allocated iterator associated to @p
@@ -651,7 +649,7 @@ EAPI Eina_Iterator *eina_inlist_iterator_new(const Eina_Inlist *in_list) EINA_MA
 /**
  * @brief Returns a new accessor associated to a list.
  *
- * @param in_list The list.
+ * @param[in] in_list The list.
  * @return A new accessor.
  *
  * This function returns a newly allocated accessor associated to
@@ -663,13 +661,12 @@ EAPI Eina_Iterator *eina_inlist_iterator_new(const Eina_Inlist *in_list) EINA_MA
 EAPI Eina_Accessor *eina_inlist_accessor_new(const Eina_Inlist *in_list) EINA_MALLOC EINA_WARN_UNUSED_RESULT;
 
 /**
- * @brief Insert a new node into a sorted list.
+ * @brief Inserts a new node into a sorted list.
  *
- * @param list The given linked list, @b must be sorted.
- * @param item list node to insert, must not be @c NULL.
- * @param func The function called for the sort.
+ * @param[in,out] list The given linked list, @b must be sorted.
+ * @param[in] item List node to insert, must not be @c NULL.
+ * @param[in] func The function called for the sort.
  * @return A list pointer.
- * @since 1.1.0
  *
  * This function inserts item into a linked list assuming it was
  * sorted and the result will be sorted. If @p list is @c NULL, item
@@ -682,13 +679,16 @@ EAPI Eina_Accessor *eina_inlist_accessor_new(const Eina_Inlist *in_list) EINA_MA
  * lists do not have O(1) access time, so walking to the correct node
  * can be costly, consider worst case to be almost O(n) pointer
  * dereference (list walk).
+ *
+ * @since 1.1.0
  */
 EAPI Eina_Inlist *eina_inlist_sorted_insert(Eina_Inlist *list, Eina_Inlist *item, Eina_Compare_Cb func) EINA_ARG_NONNULL(2, 3) EINA_WARN_UNUSED_RESULT;
 
 /**
- * @brief Create state with valid data in it.
+ * @brief Creates state with valid data in it.
  *
  * @return A valid Eina_Inlist_Sorted_State.
+ *
  * @since 1.1.0
  *
  * See eina_inlist_sorted_state_insert() for more information.
@@ -696,11 +696,12 @@ EAPI Eina_Inlist *eina_inlist_sorted_insert(Eina_Inlist *list, Eina_Inlist *item
 EAPI Eina_Inlist_Sorted_State *eina_inlist_sorted_state_new(void);
 
 /**
- * @brief Force an Eina_Inlist_Sorted_State to match the content of a list.
+ * @brief Forces an Eina_Inlist_Sorted_State to match the content of a list.
  *
- * @param state The state to update
- * @param list The list to match
+ * @param[in,out] state The state to update
+ * @param[in] list The list to match
  * @return The number of item in the actually in the list
+ *
  * @since 1.1.0
  *
  * See eina_inlist_sorted_state_insert() for more information. This function is
@@ -710,9 +711,10 @@ EAPI Eina_Inlist_Sorted_State *eina_inlist_sorted_state_new(void);
 EAPI int eina_inlist_sorted_state_init(Eina_Inlist_Sorted_State *state, Eina_Inlist *list);
 
 /**
- * @brief Free an Eina_Inlist_Sorted_State.
+ * @brief Frees an Eina_Inlist_Sorted_State.
+ *
+ * @param[in,out] state The state to destroy
  *
- * @param state The state to destroy
  * @since 1.1.0
  *
  * See eina_inlist_sorted_state_insert() for more information.
@@ -720,21 +722,21 @@ EAPI int eina_inlist_sorted_state_init(Eina_Inlist_Sorted_State *state, Eina_Inl
 EAPI void eina_inlist_sorted_state_free(Eina_Inlist_Sorted_State *state);
 
 /**
- * @brief Insert a new node into a sorted list.
+ * @brief Inserts a new node into a sorted list.
  *
- * @param list The given linked list, @b must be sorted.
- * @param item list node to insert, must not be @c NULL.
- * @param func The function called for the sort.
- * @param state The current array for initial dichotomic search
+ * @param[in,out] list The given linked list, @b must be sorted.
+ * @param[in] item list node to insert, must not be @c NULL.
+ * @param[in] func The function called for the sort.
+ * @param[in,out] state The current array for initial dichotomic search
  * @return A list pointer.
  * @since 1.1.0
  *
- * This function inserts item into a linked list assuming @p state match
- * the exact content order of the list. It use @p state to do a fast
+ * This function inserts item into a linked list assuming @p state matches
+ * the exact content order of the list. It uses @p state to do a fast
  * first step dichotomic search before starting to walk the inlist itself.
- * This make this code much faster than eina_inlist_sorted_insert() as it
+ * This makes this code much faster than eina_inlist_sorted_insert() as it
  * doesn't need to walk the list at all. The result is of course a sorted
- * list with an updated state.. If @p list is @c NULLL, item
+ * list with an updated state. If @p list is @c NULL, item
  * is returned. On success, a new list pointer that should be
  * used in place of the one given to this function is
  * returned. Otherwise, the old pointer is returned.
@@ -742,8 +744,8 @@ EAPI void eina_inlist_sorted_state_free(Eina_Inlist_Sorted_State *state);
  * @note O(log2(n)) comparisons (calls to @p func) average/worst case
  * performance. As said in eina_list_search_sorted_near_list(),
  * lists do not have O(1) access time, so walking to the correct node
- * can be costly, but this version try to minimize that by making it a
- * O(log2(n)) for number small number. After n == 256, it start to add a
+ * can be costly, but this version tries to minimize that by making it a
+ * O(log2(n)) for number small number. After n == 256, it starts to add a
  * linear cost again. Consider worst case to be almost O(n) pointer
  * dereference (list walk).
  */
@@ -752,10 +754,10 @@ EAPI Eina_Inlist *eina_inlist_sorted_state_insert(Eina_Inlist *list,
 						  Eina_Compare_Cb func,
 						  Eina_Inlist_Sorted_State *state);
 /**
- * @brief Sort a list according to the ordering func will return.
+ * @brief Sorts a list according to the ordering func will return.
  *
- * @param head The list handle to sort.
- * @param func A function pointer that can handle comparing the list data
+ * @param[in,out] head The list handle to sort.
+ * @param[in] func A function pointer that can handle comparing the list data
  * nodes.
  * @return the new head of list.
  *
@@ -797,18 +799,18 @@ EAPI Eina_Inlist *eina_inlist_sorted_state_insert(Eina_Inlist *list,
  */
 EAPI Eina_Inlist *eina_inlist_sort(Eina_Inlist *head, Eina_Compare_Cb func);
 
-/* This two macros are helpers for the _FOREACH ones, don't use them */
+/* These two macros are helpers for the _FOREACH ones, don't use them */
 /**
  * @def _EINA_INLIST_OFFSET
- * @param ref The reference to be used.
+ * @param[in,out] ref The reference to be used.
  */
 #define _EINA_INLIST_OFFSET(ref)         ((char *)&(ref)->__in_list - (char *)(ref))
 
 #if !defined(__cplusplus)
 /**
  * @def _EINA_INLIST_CONTAINER
- * @param ref The reference to be used.
- * @param ptr The pointer to be used.
+ * @param[in,out] ref The reference to be used.
+ * @param[out] ptr The pointer to be used.
  */
 #define _EINA_INLIST_CONTAINER(ref, ptr) (void *)((char *)(ptr) - \
                                                   _EINA_INLIST_OFFSET(ref))
@@ -823,9 +825,9 @@ EAPI Eina_Inlist *eina_inlist_sort(Eina_Inlist *head, Eina_Compare_Cb func);
 
 /**
  * @def EINA_INLIST_FOREACH
- * @param list The list to iterate on.
- * @param it The pointer to the list item, i.e. a pointer to each item
- * that is part of the list.
+ * @param[in,out] list The list to iterate on.
+ * @param[out] it The pointer to the list item, i.e. a pointer to each
+ *             item that is part of the list.
  */
 #define EINA_INLIST_FOREACH(list, it)                                     \
   for (it = NULL, it = (list ? _EINA_INLIST_CONTAINER(it, list) : NULL); it; \
@@ -833,13 +835,14 @@ EAPI Eina_Inlist *eina_inlist_sort(Eina_Inlist *head, Eina_Compare_Cb func);
 
 /**
  * @def EINA_INLIST_FOREACH_SAFE
- * @param list The list to iterate on.
- * @param list2 Auxiliary Eina_Inlist variable so we can save the pointer to the
- * next element, allowing us to free/remove the current one. Note that this
- * macro is only safe if the next element is not removed. Only the current one
- * is allowed to be removed.
- * @param it The pointer to the list item, i.e. a pointer to each item
- * that is part of the list.
+ * @param[in,out] list The list to iterate on.
+ * @param[out] list2 Auxiliary Eina_Inlist variable so we can save the
+ *             pointer to the next element, allowing us to free/remove
+ *             the current one. Note that this macro is only safe if the
+ *             next element is not removed. Only the current one is
+ *             allowed to be removed.
+ * @param[out] it The pointer to the list item, i.e. a pointer to each
+ *             item that is part of the list.
  */
 #define EINA_INLIST_FOREACH_SAFE(list, list2, it) \
    for (it = NULL, it = (list ? _EINA_INLIST_CONTAINER(it, list) : NULL), list2 = it ? EINA_INLIST_GET(it)->next : NULL; \
@@ -848,9 +851,9 @@ EAPI Eina_Inlist *eina_inlist_sort(Eina_Inlist *head, Eina_Compare_Cb func);
 
 /**
  * @def EINA_INLIST_REVERSE_FOREACH
- * @param list The list to traversed in reverse order.
- * @param it The pointer to the list item, i.e. a pointer to each item
- * that is part of the list.
+ * @param[in,out] list The list to traverse in reverse order.
+ * @param[out] it The pointer to the list item, i.e. a pointer to each
+ *             item that is part of the list.
  */
 #define EINA_INLIST_REVERSE_FOREACH(list, it)                                \
   for (it = NULL, it = (list ? _EINA_INLIST_CONTAINER(it, list->last) : NULL); \
@@ -858,10 +861,11 @@ EAPI Eina_Inlist *eina_inlist_sort(Eina_Inlist *head, Eina_Compare_Cb func);
 
 /**
  * @def EINA_INLIST_REVERSE_FOREACH_FROM
- * @param list The last list to traversed in reverse order.
- * @param it The pointer to the list item, i.e. a pointer to each item
- * that is part of the list.
+ * @param[in,out] list The last list to traverse in reverse order.
+ * @param[in] it The pointer to the list item, i.e. a pointer to each
+ *            item that is part of the list.
  * @see EINA_INLIST_REVERSE_FOREACH()
+ *
  * @since 1.8
  *
  * EINA_INLIST_REVERSE_FOREACH() starts from last list of the given list.
@@ -873,9 +877,9 @@ EAPI Eina_Inlist *eina_inlist_sort(Eina_Inlist *head, Eina_Compare_Cb func);
 
 /**
  * @def EINA_INLIST_FREE
- * @param list The list to free.
- * @param it The pointer to the list item, i.e. a pointer to each item
- * that is part of the list.
+ * @param[in,out] list The list to free.
+ * @param[in] it The pointer to the list item, i.e. a pointer to each item
+ *            that is part of the list.
  *
  * NOTE: it is the duty of the body loop to properly remove the item from the
  * inlist and free it. This function will turn into a infinite loop if you
