@@ -327,7 +327,7 @@ typedef struct _Efl_Access_Relation
  */
 #define EFL_ACCESS_OBJECT_MIXIN efl_access_object_mixin_get()
 
-EWAPI const Efl_Class *efl_access_object_mixin_get(void);
+EWAPI const Efl_Class *efl_access_object_mixin_get(void) EINA_CONST;
 
 #ifdef EFL_BETA_API_SUPPORT
 #ifdef EFL_ACCESS_OBJECT_PROTECTED
