@@ -29,6 +29,6 @@ typedef Eo Efl_Ui_Default_Item;
  */
 #define EFL_UI_DEFAULT_ITEM_CLASS efl_ui_default_item_class_get()
 
-EWAPI const Efl_Class *efl_ui_default_item_class_get(void);
+EWAPI const Efl_Class *efl_ui_default_item_class_get(void) EINA_CONST;
 
 #endif
