@@ -16,7 +16,7 @@ typedef Eo Efl_Ui_Spotlight_Fade_Manager;
 #ifdef EFL_BETA_API_SUPPORT
 #define EFL_UI_SPOTLIGHT_FADE_MANAGER_CLASS efl_ui_spotlight_fade_manager_class_get()
 
-EWAPI const Efl_Class *efl_ui_spotlight_fade_manager_class_get(void);
+EWAPI const Efl_Class *efl_ui_spotlight_fade_manager_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
