@@ -13,7 +13,6 @@ typedef Eo Efl_Ui_Widget_Factory;
 
 
 #endif
-#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Efl Ui Factory that provides @ref Efl_Ui_Widget.
  *
@@ -21,11 +20,13 @@ typedef Eo Efl_Ui_Widget_Factory;
  * their @ref efl_ui_widget_style_get if it was connected with
  * @ref efl_ui_property_bind "$style".
  *
+ * @since 1.23
+ *
  * @ingroup Efl_Ui_Widget_Factory
  */
 #define EFL_UI_WIDGET_FACTORY_CLASS efl_ui_widget_factory_class_get()
 
-EWAPI const Efl_Class *efl_ui_widget_factory_class_get(void);
+EWAPI const Efl_Class *efl_ui_widget_factory_class_get(void) EINA_CONST;
 
 /**
  * @brief Define the class of the item returned by this factory.
@@ -33,6 +34,8 @@ EWAPI const Efl_Class *efl_ui_widget_factory_class_get(void);
  * @param[in] obj The object.
  * @param[in] klass The class identifier to create item from.
  *
+ * @since 1.23
+ *
  * @ingroup Efl_Ui_Widget_Factory
  */
 EOAPI void efl_ui_widget_factory_item_class_set(Eo *obj, const Efl_Class *klass);
@@ -44,9 +47,10 @@ EOAPI void efl_ui_widget_factory_item_class_set(Eo *obj, const Efl_Class *klass)
  *
  * @return The class identifier to create item from.
  *
+ * @since 1.23
+ *
  * @ingroup Efl_Ui_Widget_Factory
  */
 EOAPI const Efl_Class *efl_ui_widget_factory_item_class_get(const Eo *obj);
-#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
