@@ -21,7 +21,7 @@ typedef Eo Efl_Ui_Widget_Focus_Manager;
  */
 #define EFL_UI_WIDGET_FOCUS_MANAGER_MIXIN efl_ui_widget_focus_manager_mixin_get()
 
-EWAPI const Efl_Class *efl_ui_widget_focus_manager_mixin_get(void);
+EWAPI const Efl_Class *efl_ui_widget_focus_manager_mixin_get(void) EINA_CONST;
 
 #ifdef EFL_UI_WIDGET_FOCUS_MANAGER_PROTECTED
 /**
