@@ -38,7 +38,7 @@ typedef enum
  */
 #define ELM_CODE_WIDGET_CLASS elm_code_widget_class_get()
 
-EWAPI const Efl_Class *elm_code_widget_class_get(void);
+EWAPI const Efl_Class *elm_code_widget_class_get(void) EINA_CONST;
 
 /**
  * @brief The underlying code object that this widget renders. This can only be
