@@ -20,7 +20,7 @@ typedef Eo Elm_Fileselector_Entry_Part;
  */
 #define ELM_FILESELECTOR_ENTRY_PART_CLASS elm_fileselector_entry_part_class_get()
 
-EWAPI const Efl_Class *elm_fileselector_entry_part_class_get(void);
+EWAPI const Efl_Class *elm_fileselector_entry_part_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
