@@ -20,7 +20,7 @@ typedef Eo Elm_Flip_Part;
  */
 #define ELM_FLIP_PART_CLASS elm_flip_part_class_get()
 
-EWAPI const Efl_Class *elm_flip_part_class_get(void);
+EWAPI const Efl_Class *elm_flip_part_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
